from dotenv import dotenv_values
from collections import defaultdict
from pydantic import BaseModel

"""
    Load environment variables with a specific prefix, validate them using the given Pydantic schema,
    and return an instance of the schema.

    example .env: 
    # h3ask123sjasl
    h3ask123sjasl_API_KEY=your_api_key_1
    h3ask123sjasl_SOMETHING_ELSE=value_1  
    
    :param env_file: Path to the .env file.
    :param prefix: Prefix for environment variables (e.g., "PRACTICE_1_").
    :param schema: A Pydantic model class to validate the loaded data.
    :return: An instance of the Pydantic model with the loaded data.
    """

def load_prefixed_env(env_file : str, id_as_prefix : str, schema : BaseModel): 
    # loading the env_file 
    env_data = dotenv_values(env_file)
    # updating the prefix 
    prefix = f"{id_as_prefix}_"
    # extracting the values from the key 
    data_filtered_by_id = { 
        key[len(prefix):]: value 
        for key, value in env_data 
        if key.startswith(prefix) }
    # try validating the schema a creating an object based on the Pydantic Model 
    return schema(**data_filtered_by_id )  # "**" unpacks the dictionary into single key, value pairs
    





from urllib.parse import urlparse
import os

def isUrl(path):
    try:
        parsedUrl = urlparse(path)
        # Check if the scheme (protocol) is either 'http' or 'https'
        isValid = all([
            parsedUrl.scheme,
            parsedUrl.netloc,
            parsedUrl.scheme in ['http', 'https']
        ])

        return isValid 
        
    except ValueError:
        return False


# src/taler_shared/__init__.py

# Import and expose modules
from .utils import isUrl
from .api import APIClient
from .api.parse_for_apis import parseToQueryParams
from .environment.load_env_variables import load_prefixed_env




from setuptools import setup, find_packages

setup(
    name='taler_shared',
    version='0.2.1',
    package_dir={"": "src"},
     packages=find_packages(where="src"),
    install_requires=[
        "certifi>=2024.2.2",
        "pydantic>=1.8.0",
        "requests>=2.31.0",
        "setuptools>=61.0.0",
        "python-dotenv>=1.0.0"
    ],
)